[asterisk-commits] russell: branch 1.4 r168561 - in /branches/1.4: apps/ channels/ funcs/ includ...

SVN commits to the Asterisk project asterisk-commits at lists.digium.com
Tue Jan 13 13:13:05 CST 2009


Author: russell
Date: Tue Jan 13 13:13:05 2009
New Revision: 168561

URL: http://svn.digium.com/svn-view/asterisk?view=rev&rev=168561
Log:
Revert unnecessary indications API change from rev 122314

Modified:
    branches/1.4/apps/app_disa.c
    branches/1.4/apps/app_read.c
    branches/1.4/channels/chan_misdn.c
    branches/1.4/funcs/func_channel.c
    branches/1.4/include/asterisk/channel.h
    branches/1.4/include/asterisk/indications.h
    branches/1.4/main/app.c
    branches/1.4/main/channel.c
    branches/1.4/main/indications.c
    branches/1.4/res/res_indications.c
    branches/1.4/res/snmp/agent.c

Modified: branches/1.4/apps/app_disa.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/apps/app_disa.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/apps/app_disa.c (original)
+++ branches/1.4/apps/app_disa.c Tue Jan 13 13:13:05 2009
@@ -98,7 +98,7 @@
 
 static void play_dialtone(struct ast_channel *chan, char *mailbox)
 {
-	const struct ind_tone_zone_sound *ts = NULL;
+	const struct tone_zone_sound *ts = NULL;
 	if(ast_app_has_voicemail(mailbox, NULL))
 		ts = ast_get_indication_tone(chan->zone, "dialrecall");
 	else

Modified: branches/1.4/apps/app_read.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/apps/app_read.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/apps/app_read.c (original)
+++ branches/1.4/apps/app_read.c Tue Jan 13 13:13:05 2009
@@ -92,7 +92,7 @@
 	int maxdigits = 255;
 	int tries = 1, to = 0, x = 0;
 	char *argcopy = NULL;
-	struct ind_tone_zone_sound *ts;
+	struct tone_zone_sound *ts;
 	struct ast_flags flags = {0};
 
 	 AST_DECLARE_APP_ARGS(arglist,

Modified: branches/1.4/channels/chan_misdn.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/channels/chan_misdn.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/channels/chan_misdn.c (original)
+++ branches/1.4/channels/chan_misdn.c Tue Jan 13 13:13:05 2009
@@ -382,7 +382,7 @@
 	 * \brief Tone zone sound used for dialtone generation.
 	 * \note Used as a boolean.  Non-NULL to prod generation if enabled. 
 	 */
-	const struct ind_tone_zone_sound *ts;
+	const struct tone_zone_sound *ts;
 	
 	/*!
 	 * \brief Enables overlap dialing for the set amount of seconds.  (0 = Disabled)
@@ -3079,7 +3079,7 @@
 
 static int dialtone_indicate(struct chan_list *cl)
 {
-	const struct ind_tone_zone_sound *ts = NULL;
+	const struct tone_zone_sound *ts = NULL;
 	struct ast_channel *ast = cl->ast;
 	int nd = 0;
 

Modified: branches/1.4/funcs/func_channel.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/funcs/func_channel.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/funcs/func_channel.c (original)
+++ branches/1.4/funcs/func_channel.c Tue Jan 13 13:13:05 2009
@@ -107,7 +107,7 @@
 	else if (!strcasecmp(data, "musicclass"))
 		locked_string_field_set(chan, musicclass, value);
 	else if (!strcasecmp(data, "tonezone")) {
-		struct ind_tone_zone *new_zone;
+		struct tone_zone *new_zone;
 		if (!(new_zone = ast_get_indication_zone(value))) {
 			ast_log(LOG_ERROR, "Unknown country code '%s' for tonezone. Check indications.conf for available country codes.\n", value);
 			ret = -1;	

Modified: branches/1.4/include/asterisk/channel.h
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/include/asterisk/channel.h?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/include/asterisk/channel.h (original)
+++ branches/1.4/include/asterisk/channel.h Tue Jan 13 13:13:05 2009
@@ -414,7 +414,7 @@
 	struct ast_cdr *cdr;				/*!< Call Detail Record */
 	enum ast_channel_adsicpe adsicpe;		/*!< Whether or not ADSI is detected on CPE */
 
-	struct ind_tone_zone *zone;				/*!< Tone zone as set in indications.conf or
+	struct tone_zone *zone;				/*!< Tone zone as set in indications.conf or
 								in the CHANNEL dialplan function */
 
 	struct ast_channel_monitor *monitor;		/*!< Channel monitoring */

Modified: branches/1.4/include/asterisk/indications.h
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/include/asterisk/indications.h?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/main/app.c (original)
+++ branches/1.4/main/app.c Tue Jan 13 13:13:05 2009
@@ -64,7 +64,7 @@
 */
 int ast_app_dtget(struct ast_channel *chan, const char *context, char *collect, size_t size, int maxlen, int timeout) 
 {
-	struct ind_tone_zone_sound *ts;
+	struct tone_zone_sound *ts;
 	int res=0, x=0;
 
 	if (maxlen > size)

Modified: branches/1.4/main/channel.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/main/channel.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/main/channel.c (original)
+++ branches/1.4/main/channel.c Tue Jan 13 13:13:05 2009
@@ -2483,7 +2483,7 @@
 	/* By using an enum, we'll get compiler warnings for values not handled 
 	 * in switch statements. */
 	enum ast_control_frame_type condition = _condition;
-	const struct ind_tone_zone_sound *ts = NULL;
+	const struct tone_zone_sound *ts = NULL;
 	int res = -1;
 
 	ast_channel_lock(chan);

Modified: branches/1.4/main/indications.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/main/indications.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/res/res_indications.c (original)
+++ branches/1.4/res/res_indications.c Tue Jan 13 13:13:05 2009
@@ -85,7 +85,7 @@
  */
 static int handle_add_indication(int fd, int argc, char *argv[])
 {
-	struct ind_tone_zone *tz;
+	struct tone_zone *tz;
 	int created_country = 0;
 	if (argc != 5) return RESULT_SHOWUSAGE;
 
@@ -119,7 +119,7 @@
  */
 static int handle_remove_indication(int fd, int argc, char *argv[])
 {
-	struct ind_tone_zone *tz;
+	struct tone_zone *tz;
 	if (argc != 3 && argc != 4) return RESULT_SHOWUSAGE;
 
 	if (argc == 3) {
@@ -148,7 +148,7 @@
  */
 static int handle_show_indications(int fd, int argc, char *argv[])
 {
-	struct ind_tone_zone *tz = NULL;
+	struct tone_zone *tz = NULL;
 	char buf[256];
 	int found_country = 0;
 
@@ -166,7 +166,7 @@
 		for (i=2; i<argc; i++) {
 			if (strcasecmp(tz->country,argv[i])==0 &&
 			    !tz->alias[0]) {
-				struct ind_tone_zone_sound* ts;
+				struct tone_zone_sound* ts;
 				if (!found_country) {
 					found_country = 1;
 					ast_cli(fd,"Country Indication      PlayList\n"
@@ -196,7 +196,7 @@
  */
 static int handle_playtones(struct ast_channel *chan, void *data)
 {
-	struct ind_tone_zone_sound *ts;
+	struct tone_zone_sound *ts;
 	int res;
 
 	if (!data || !((char*)data)[0]) {
@@ -231,7 +231,7 @@
 	struct ast_variable *v;
 	char *cxt;
 	char *c;
-	struct ind_tone_zone *tones;
+	struct tone_zone *tones;
 	const char *country = NULL;
 
 	/* that the following cast is needed, is yuk! */
@@ -284,7 +284,7 @@
 				c = countries;
 				country = strsep(&c,",");
 				while (country) {
-					struct ind_tone_zone* azone;
+					struct tone_zone* azone;
 					if (!(azone = ast_calloc(1, sizeof(*azone)))) {
 						ast_config_destroy(cfg);
 						return -1;
@@ -300,7 +300,7 @@
 				}
 			} else {
 				/* add tone to country */
-				struct ind_tone_zone_sound *ps,*ts;
+				struct tone_zone_sound *ps,*ts;
 				for (ps=NULL,ts=tones->tones; ts; ps=ts, ts=ts->next) {
 					if (strcasecmp(v->name,ts->name)==0) {
 						/* already there */

Modified: branches/1.4/res/snmp/agent.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/res/snmp/agent.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/res/snmp/agent.c (original)
+++ branches/1.4/res/snmp/agent.c Tue Jan 13 13:13:05 2009
@@ -621,7 +621,7 @@
 								  int exact, size_t *var_len, WriteMethod **write_method)
 {
     static unsigned long long_ret;
-    struct ind_tone_zone *tz = NULL;
+    struct tone_zone *tz = NULL;
 
     if (header_generic(vp, name, length, exact, var_len, write_method))
 		return NULL;
@@ -651,7 +651,7 @@
 									   int exact, size_t *var_len, WriteMethod **write_method)
 {
     static unsigned long long_ret;
-    struct ind_tone_zone *tz = NULL;
+    struct tone_zone *tz = NULL;
     int i;
 
     if (header_simple_table(vp, name, length, exact, var_len, write_method, -1))




More information about the asterisk-commits mailing list
--- branches/1.4/include/asterisk/indications.h (original)
+++ branches/1.4/include/asterisk/indications.h Tue Jan 13 13:13:05 2009
@@ -34,8 +34,8 @@
 
 #include "asterisk/lock.h"
 
-struct ind_tone_zone_sound {
-	struct ind_tone_zone_sound *next;		/* next element */
+struct tone_zone_sound {
+	struct tone_zone_sound *next;		/* next element */
 	const char *name;			/* Identifing name */
 	const char *data;			/* Actual zone description */
 	/* Description is a series of tones of the format:
@@ -45,33 +45,33 @@
 	   specified in milliseconds */
 };
 
-struct ind_tone_zone {
-	struct ind_tone_zone* next;				/* next in list */
+struct tone_zone {
+	struct tone_zone* next;				/* next in list */
 	char country[5];				/* Country code */
 	char alias[5];					/* is this an alias? */
 	char description[40];				/* Description */
 	int  nrringcadence;				/* # registered ringcadence elements */
 	int *ringcadence;				/* Ring cadence */
-	struct ind_tone_zone_sound *tones;			/* The known tones for this zone */
+	struct tone_zone_sound *tones;			/* The known tones for this zone */
 };
 
 /* set the default tone country */
 int ast_set_indication_country(const char *country);
 
 /* locate ind_tone_zone, given the country. if country == NULL, use the default country */
-struct ind_tone_zone *ast_get_indication_zone(const char *country);
-/* locate a ind_tone_zone_sound, given the ind_tone_zone. if ind_tone_zone == NULL, use the default ind_tone_zone */
-struct ind_tone_zone_sound *ast_get_indication_tone(const struct ind_tone_zone *zone, const char *indication);
+struct tone_zone *ast_get_indication_zone(const char *country);
+/* locate a tone_zone_sound, given the tone_zone. if tone_zone == NULL, use the default tone_zone */
+struct tone_zone_sound *ast_get_indication_tone(const struct tone_zone *zone, const char *indication);
 
 /* add a new country, if country exists, it will be replaced. */
-int ast_register_indication_country(struct ind_tone_zone *country);
+int ast_register_indication_country(struct tone_zone *country);
 /* remove an existing country and all its indications, country must exist */
 int ast_unregister_indication_country(const char *country);
 /* add a new indication to a ind_tone_zone. ind_tone_zone must exist. if the indication already
  * exists, it will be replaced. */
-int ast_register_indication(struct ind_tone_zone *zone, const char *indication, const char *tonelist);
-/* remove an existing ind_tone_zone's indication. ind_tone_zone must exist */
-int ast_unregister_indication(struct ind_tone_zone *zone, const char *indication);
+int ast_register_indication(struct tone_zone *zone, const char *indication, const char *tonelist);
+/* remove an existing tone_zone's indication. tone_zone must exist */
+int ast_unregister_indication(struct tone_zone *zone, const char *indication);
 
 /* Start a tone-list going */
 int ast_playtones_start(struct ast_channel *chan, int vol, const char* tonelist, int interruptible);
@@ -79,10 +79,10 @@
 void ast_playtones_stop(struct ast_channel *chan);
 
 /* support for walking through a list of indications */
-struct ind_tone_zone *ast_walk_indications(const struct ind_tone_zone *cur);
+struct tone_zone *ast_walk_indications(const struct tone_zone *cur);
 
 #if 0
-extern struct ind_tone_zone *ind_tone_zones;
+extern struct tone_zone *tone_zones;
 extern ast_mutex_t tzlock;
 #endif
 
@@ -45,33 +45,33 @@
 /* remove an existing country and all its indications, country must exist */
 int ast_unregister_indication_country(const char *country);
-/* add a new indication to a ind_tone_zone. ind_tone_zone must exist. if the indication already
+/* add a new indication to a tone_zone. tone_zone must exist. if the indication already
  * exists, it will be replaced. */

Modified: branches/1.4/main/app.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/main/app.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================
--- branches/1.4/main/indications.c (original)
+++ branches/1.4/main/indications.c Tue Jan 13 13:13:05 2009
@@ -329,21 +329,21 @@
 
 /*--------------------------------------------*/
 
-static struct ind_tone_zone *ind_tone_zones;
-static struct ind_tone_zone *current_tonezone;
-
-/* Protect the ind_tone_zones list (highly unlikely that two things would change
+static struct tone_zone *tone_zones;
+static struct tone_zone *current_tonezone;
+
+/* Protect the tone_zones list (highly unlikely that two things would change
  * it at the same time, but still! */
 AST_MUTEX_DEFINE_STATIC(tzlock);
 
-struct ind_tone_zone *ast_walk_indications(const struct ind_tone_zone *cur)
-{
-	struct ind_tone_zone *tz;
+struct tone_zone *ast_walk_indications(const struct tone_zone *cur)
+{
+	struct tone_zone *tz;
 
 	if (cur == NULL)
-		return ind_tone_zones;
-	ast_mutex_lock(&tzlock);
-	for (tz = ind_tone_zones; tz; tz = tz->next)
+		return tone_zones;
+	ast_mutex_lock(&tzlock);
+	for (tz = tone_zones; tz; tz = tz->next)
 		if (tz == cur)
 			break;
 	if (tz)
@@ -356,7 +356,7 @@
 int ast_set_indication_country(const char *country)
 {
 	if (country) {
-		struct ind_tone_zone *z = ast_get_indication_zone(country);
+		struct tone_zone *z = ast_get_indication_zone(country);
 		if (z) {
 			if (option_verbose > 2)
 				ast_verbose(VERBOSE_PREFIX_3 "Setting default indication country to '%s'\n",country);
@@ -367,22 +367,22 @@
 	return 1; /* not found */
 }
 
-/* locate ind_tone_zone, given the country. if country == NULL, use the default country */
-struct ind_tone_zone *ast_get_indication_zone(const char *country)
-{
-	struct ind_tone_zone *tz;
+/* locate tone_zone, given the country. if country == NULL, use the default country */
+struct tone_zone *ast_get_indication_zone(const char *country)
+{
+	struct tone_zone *tz;
 	int alias_loop = 0;
 
 	if (ast_strlen_zero(country)) {
 		/* No country specified?  Return the default or the first in the list */
-		return current_tonezone ? current_tonezone : ind_tone_zones;
+		return current_tonezone ? current_tonezone : tone_zones;
 	}
 
 	ast_mutex_lock(&tzlock);
 	do {
-		for (tz=ind_tone_zones; tz; tz=tz->next) {
+		for (tz=tone_zones; tz; tz=tz->next) {
 			if (strcasecmp(country,tz->country)==0) {
-				/* ind_tone_zone found */
+				/* tone_zone found */
 				if (tz->alias && tz->alias[0]) {
 					country = tz->alias;
 					break;
@@ -399,16 +399,16 @@
 	return 0;
 }
 
-/* locate a ind_tone_zone_sound, given the ind_tone_zone. if ind_tone_zone == NULL, use the default ind_tone_zone */
-struct ind_tone_zone_sound *ast_get_indication_tone(const struct ind_tone_zone *zone, const char *indication)
-{
-	struct ind_tone_zone_sound *ts;
+/* locate a tone_zone_sound, given the tone_zone. if tone_zone == NULL, use the default tone_zone */
+struct tone_zone_sound *ast_get_indication_tone(const struct tone_zone *zone, const char *indication)
+{
+	struct tone_zone_sound *ts;
 
 	/* we need some tonezone, pick the first */
 	if (zone == NULL && current_tonezone)
 		zone = current_tonezone;	/* default country? */
-	if (zone == NULL && ind_tone_zones)
-		zone = ind_tone_zones;		/* any country? */
+	if (zone == NULL && tone_zones)
+		zone = tone_zones;		/* any country? */
 	if (zone == NULL)
 		return 0;	/* not a single country insight */
 
@@ -425,11 +425,11 @@
 	return 0;
 }
 
-/* helper function to delete a ind_tone_zone in its entirety */
-static inline void free_zone(struct ind_tone_zone* zone)
+/* helper function to delete a tone_zone in its entirety */
+static inline void free_zone(struct tone_zone* zone)
 {
 	while (zone->tones) {
-		struct ind_tone_zone_sound *tmp = zone->tones->next;
+		struct tone_zone_sound *tmp = zone->tones->next;
 		free((void*)zone->tones->name);
 		free((void*)zone->tones->data);
 		free(zone->tones);
@@ -443,19 +443,19 @@
 /*--------------------------------------------*/
 
 /* add a new country, if country exists, it will be replaced. */
-int ast_register_indication_country(struct ind_tone_zone *zone)
-{
-	struct ind_tone_zone *tz,*pz;
-
-	ast_mutex_lock(&tzlock);
-	for (pz=NULL,tz=ind_tone_zones; tz; pz=tz,tz=tz->next) {
+int ast_register_indication_country(struct tone_zone *zone)
+{
+	struct tone_zone *tz,*pz;
+
+	ast_mutex_lock(&tzlock);
+	for (pz=NULL,tz=tone_zones; tz; pz=tz,tz=tz->next) {
 		if (strcasecmp(zone->country,tz->country)==0) {
 			/* ind_tone_zone already there, replace */
 			zone->next = tz->next;
 			if (pz)
 				pz->next = zone;
 			else
-				ind_tone_zones = zone;
+				tone_zones = zone;
 			/* if we are replacing the default zone, re-point it */
 			if (tz == current_tonezone)
 				current_tonezone = zone;
@@ -470,7 +470,7 @@
 	if (pz)
 		pz->next = zone;
 	else
-		ind_tone_zones = zone;
+		tone_zones = zone;
 	ast_mutex_unlock(&tzlock);
 
 	if (option_verbose > 2)
@@ -482,21 +482,21 @@
  * Also, all countries which are an alias for the specified country are removed. */
 int ast_unregister_indication_country(const char *country)
 {
-	struct ind_tone_zone *tz, *pz = NULL, *tmp;
+	struct tone_zone *tz, *pz = NULL, *tmp;
 	int res = -1;
 
 	ast_mutex_lock(&tzlock);
-	tz = ind_tone_zones;
+	tz = tone_zones;
 	while (tz) {
 		if (country==NULL ||
 		    (strcasecmp(country, tz->country)==0 ||
 		     strcasecmp(country, tz->alias)==0)) {
-			/* ind_tone_zone found, remove */
+			/* tone_zone found, remove */
 			tmp = tz->next;
 			if (pz)
 				pz->next = tmp;
 			else
-				ind_tone_zones = tmp;
+				tone_zones = tmp;
 			/* if we are unregistering the default country, w'll notice */
 			if (tz == current_tonezone) {
 				ast_log(LOG_NOTICE,"Removed default indication country '%s'\n",tz->country);
@@ -505,8 +505,8 @@
 			if (option_verbose > 2)
 				ast_verbose(VERBOSE_PREFIX_3 "Unregistered indication country '%s'\n",tz->country);
 			free_zone(tz);
-			if (ind_tone_zones == tz)
-				ind_tone_zones = tmp;
+			if (tone_zones == tz)
+				tone_zones = tmp;
 			tz = tmp;
 			res = 0;
 		}
@@ -520,11 +520,11 @@
 	return res;
 }
 
 /* add a new indication to a ind_tone_zone. ind_tone_zone must exist. if the indication already
  * exists, it will be replaced. */
-int ast_register_indication(struct ind_tone_zone *zone, const char *indication, const char *tonelist)
-{
-	struct ind_tone_zone_sound *ts,*ps;
+int ast_register_indication(struct tone_zone *zone, const char *indication, const char *tonelist)
+{
+	struct tone_zone_sound *ts,*ps;
 
 	/* is it an alias? stop */
 	if (zone->alias[0])
@@ -560,9 +560,9 @@
 }
 
 /* remove an existing country's indication. Both country and indication must exist */
-int ast_unregister_indication(struct ind_tone_zone *zone, const char *indication)
-{
-	struct ind_tone_zone_sound *ts,*ps = NULL, *tmp;
+int ast_unregister_indication(struct tone_zone *zone, const char *indication)
+{
+	struct tone_zone_sound *ts,*ps = NULL, *tmp;
 	int res = -1;
 
 	/* is it an alias? stop */
@@ -443,19 +443,19 @@
 		if (strcasecmp(zone->country,tz->country)==0) {
-			/* ind_tone_zone already there, replace */
+			/* tone_zone already there, replace */
 			zone->next = tz->next;
 			if (pz)
@@ -520,11 +520,11 @@
 }
 
-/* add a new indication to a ind_tone_zone. ind_tone_zone must exist. if the indication already
+/* add a new indication to a tone_zone. tone_zone must exist. if the indication already
  * exists, it will be replaced. */

Modified: branches/1.4/res/res_indications.c
URL: http://svn.digium.com/svn-view/asterisk/branches/1.4/res/res_indications.c?view=diff&rev=168561&r1=168560&r2=168561
==============================================================================